Blazar, the OpenStack Reservation Service
=========================================

Blazar is the *Resource Reservation Service* for OpenStack.

If you are new to Blazar, please start with the :ref:`Introduction`.

Installation Guide
------------------

.. toctree::
   :maxdepth: 2

   install/index

Configuration Reference
-----------------------
.. toctree::
   :maxdepth: 2

   configuration/index

CLI Reference
-------------

.. toctree::
   :maxdepth: 2

   cli/index

API Reference
-------------

.. toctree::
   :maxdepth: 2

   restapi/index

User Guide
----------

.. toctree::
    :maxdepth: 2

    user/index

Admin Guide
-----------

.. toctree::
    :maxdepth: 2

    admin/index

For Contributors
----------------

.. toctree::
   :maxdepth: 2

   contributor/index

.. toctree::
   :maxdepth: 2

   reference/index

Specs
-----

.. toctree::

   Blazar Specifications <https://specs.openstack.org/openstack/blazar-specs/index.html>

Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`
